@@ -689,7 +689,9 @@ LoadDicePixmaps (void)
 void
 update_undo_sensitivity (void)
 {
-  g_simple_action_set_enabled (((GSimpleAction *) undo_action), UndoVisible ());
+  /* Unfortunately, this does not change the state of undo button in app menu :( */
+  gboolean enable = UndoVisible ();
+  g_action_group_query_action (G_ACTION_GROUP (application), "undo", &enable, NULL, NULL, NULL, NULL);
 }
 
 static void
@@ -849,6 +851,12 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+  /*
+   * Required because the binary doesn't match the desktop file.
+   * Has to be before the call to g_option_context_parse.
+   */
+  g_set_prgname ("gtali");
+
   application = gtk_application_new ("org.gnome.tali", 0);
   g_signal_connect (application, "activate", G_CALLBACK (GyahtzeeCreateMainWindow), NULL);
 
@@ -914,7 +922,7 @@ main (int argc, char *argv[])
       exit(0);
   }
 
-  highscores = games_scores_new ("gtali",
+  highscores = games_scores_new ("tali",
                                  category_array, G_N_ELEMENTS (category_array),
                                  "game type", NULL,
                                  0 /* default category */,
